@@ -1,5 +1,7 @@
+mod dummy;
 mod filter;
 mod projection;
 
+pub(crate) use dummy::Dummy;
 pub(crate) use filter::*;
 pub(crate) use projection::*;
