@@ -2,6 +2,7 @@ from __future__ import annotations
 
 from datetime import datetime, timedelta
 
+import numpy as np
 import pytest
 
 import polars as pl
@@ -178,21 +179,29 @@ def test_groupby_dynamic_flat_agg_4814() -> None:
 
 
 def test_groupby_dynamic_overlapping_groups_flat_apply_multiple_5038() -> None:
-    assert (
-        pl.DataFrame(
-            {
-                "a": [
-                    datetime(2021, 1, 1) + timedelta(seconds=2**i) for i in range(10)
-                ],
-                "b": [float(i) for i in range(10)],
-            }
+    every: str | timedelta
+    period: str | timedelta
+
+    for every, period in (  # type: ignore[assignment]
+        ("10s", timedelta(seconds=100)),
+        (timedelta(seconds=10), "100s"),
+    ):
+        assert (
+            pl.DataFrame(
+                {
+                    "a": [
+                        datetime(2021, 1, 1) + timedelta(seconds=2**i)
+                        for i in range(10)
+                    ],
+                    "b": [float(i) for i in range(10)],
+                }
+            )
+            .lazy()
+            .groupby_dynamic("a", every=every, period=period)
+            .agg([pl.col("b").var().sqrt().alias("corr")])
+        ).collect().sum().to_dict(False) == pytest.approx(
+            {"a": [None], "corr": [6.988674024215477]}
         )
-        .lazy()
-        .groupby_dynamic("a", every="10s", period="100s")
-        .agg([pl.col("b").var().sqrt().alias("corr")])
-    ).collect().sum().to_dict(False) == pytest.approx(
-        {"a": [None], "corr": [6.988674024215477]}
-    )
 
 
 def test_take_in_groupby() -> None:
@@ -212,3 +221,17 @@ def test_groupby_wildcard() -> None:
     assert df.groupby([pl.col("*")], maintain_order=True).agg(
         [pl.col("a").first().suffix("_agg")]
     ).to_dict(False) == {"a": [1, 2], "b": [1, 2], "a_agg": [1, 2]}
+
+
+def test_streaming_non_streaming_gb() -> None:
+    n = 100
+    df = pl.DataFrame({"a": np.random.randint(0, 20, n)})
+    q = df.lazy().groupby("a").agg(pl.count()).sort("a")
+    assert q.collect(allow_streaming=True).frame_equal(q.collect())
+
+    q = df.lazy().with_column(pl.col("a").cast(pl.Utf8))
+    q = q.groupby("a").agg(pl.count()).sort("a")
+    assert q.collect(allow_streaming=True).frame_equal(q.collect())
+    q = df.lazy().with_column(pl.col("a").alias("b"))
+    q = q.groupby(["a", "b"]).agg(pl.count()).sort("a")
+    assert q.collect(allow_streaming=True).frame_equal(q.collect())
